@@ -413,3 +413,23 @@ on_import_s2p_impS22_btn_clicked       (GtkButton       *button,
 void
 on_print1_activate                     (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
+
+void
+on_cable_cancel_btn_clicked            (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_cable_accept_btn_clicked            (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_cable_remove_btn_clicked            (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_cable_add_btn_clicked               (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_cable_edit_btn_clicked              (GtkButton       *button,
+                                        gpointer         user_data);
