@@ -27,8 +27,10 @@
 #include <gnome.h>
 #include <libxml/tree.h>
 
+#include "interface.h"
 #include "support.h"
 #include "callbacks.h"
+#include "cables.h"
 #include "printer.h"
 #include "main.h"
 #include "global.h"
@@ -657,32 +659,54 @@ circlist_clear(void)
 void
 circ_move_up(void)
 {
-  if (active_el_iter.stamp == 0) return;
+  GtkTreeSelection *sel;
+  GtkTreeIter *prev_iter, iter, active_iter;
+  GtkTreeModel *store;
+  GtkTreePath *active_path, *path;
+  gboolean ok;
 
-  GtkTreeIter csr, prev;
-  GtkListStore *store;
+  sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(el_view));
+  if (!gtk_tree_selection_get_selected(sel, &store, &active_iter))
+    return;
+  active_path = gtk_tree_model_get_path(store, &active_iter);
 
-  store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(el_view)));
+  prev_iter = NULL;
+  ok = gtk_tree_model_get_iter_first(store, &iter);
+  while (ok) {
+   path = gtk_tree_model_get_path(store, &iter);
+   if (gtk_tree_path_compare(active_path, path) == 0)
+     break;
+   if (prev_iter) gtk_tree_iter_free(prev_iter);
+   prev_iter = gtk_tree_iter_copy(&iter);
+   ok = gtk_tree_model_iter_next(store, &iter);
+  }
 
-  if (!gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &csr)) return;
+  if (prev_iter == NULL)
+    return;
+    
+  gtk_list_store_swap(GTK_LIST_STORE(store), &active_iter, prev_iter);
+  gtk_tree_iter_free(prev_iter);
+  recalculate_all(DST_SCREEN);
 }
 
 
 void
 circ_move_down(void)
 {
-  if (active_el_iter.stamp == 0) return;
+  GtkTreeSelection *sel;
+  GtkTreeIter *next_iter, active_iter;
+  GtkTreeModel *store;
 
-  GtkTreeIter *next;
-  GtkListStore *store;
-
-  store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(el_view)));
-
-  next = gtk_tree_iter_copy(&active_el_iter);
-  if (gtk_tree_model_iter_next(GTK_TREE_MODEL(store), next)) {
-    gtk_list_store_swap(store, &active_el_iter, next);
+  sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(el_view));
+  if (!gtk_tree_selection_get_selected(sel, &store, &active_iter))
+    return;
+    
+  next_iter = gtk_tree_iter_copy(&active_iter);
+  if (gtk_tree_model_iter_next(store, next_iter)) {
+    gtk_list_store_swap(GTK_LIST_STORE(store), &active_iter, next_iter);
   }
-  g_free(next);
+  gtk_tree_iter_free(next_iter);
+  recalculate_all(DST_SCREEN);
 }
 
 
@@ -893,3 +917,48 @@ number_elements(void)
 
   return gtk_tree_model_iter_n_children(model, NULL);
 }
+
+void
+circ_treeview_cursor_changed(GtkTreeView *treeview)
+{
+  fetch_selected_element(treeview, &act_el);
+  recalculate_all(DST_SCREEN);
+}
+
+void
+comp_stub_selcable_btn_clicked(void)
+{
+  GtkWidget *btn, 
+            *dlg = create_CableDialog();
+  int nr;
+
+  load_cable_table(dlg);
+
+  if (gtk_dialog_run(GTK_DIALOG(dlg)) == GTK_RESPONSE_ACCEPT) {
+    nr = get_selected_cable_nr(dlg);
+    if (nr != -1) {
+      show_cable_data(SEP_STUB_VAL, nr);
+    }
+  }    
+    
+  gtk_widget_destroy(dlg);
+}
+
+void
+comp_line_selcable_btn_clicked(void)
+{
+  GtkWidget *btn, 
+            *dlg = create_CableDialog();
+  int nr;
+
+  load_cable_table(dlg);
+
+  if (gtk_dialog_run(GTK_DIALOG(dlg)) == GTK_RESPONSE_ACCEPT) {
+    nr = get_selected_cable_nr(dlg);
+    if (nr != -1) {
+      show_cable_data(SEP_LINE_VAL, nr);
+    }
+  }    
+    
+  gtk_widget_destroy(dlg);
+}
