@@ -86,13 +86,14 @@ typedef struct {
 	 vec_background,		// Vector chart background color
 	 vec_font_color;		// Vector chart font color
 
-  double x_offs,			// for bitmap backgrounds
+  double arc_size[ARC_TYPES],		// Screen line width of arcs
+	 x_offs,			// for bitmap backgrounds
   	 y_offs,
          chartradius;
 
   // printer configuration
 
-  char	 prt_papersize[20],
+  char	 prt_papersize[80],
 	 prt_font_name[80];
 
   int	 prt_arc_color[ARC_TYPES],
