@@ -170,7 +170,8 @@ loglist_show(void)
   prow = g_strdup_printf("<span font_desc=\"%s\">", pref.results_font);
   trow = prow;
   for (ld = 0; ld < loglist.nr_lds; ld++) {
-    sprintf(bff, "   %11.*f MHz    ", pref.prec_mhz, loglist.freq[ld]);
+    sprintf(bff, "   %11.*f MHz    ", 
+		 pref.prec_mhz, loglist.freq[ld]);
     prow = g_strconcat(prow, bff, NULL);
     g_free(trow);
     trow = prow;
@@ -190,7 +191,9 @@ loglist_show(void)
   trow = prow;
   for (ld = 0; ld < loglist.nr_lds; ld++) {
     c = loglist.load[ld];
-    sprintf(bff, "%10.3f%+10.3f%s ", creal(c), cimag(c), pref.complex_sfx);
+    sprintf(bff, "%10.*f%+10.*f%s ", 
+		 pref.prec_imp, creal(c), pref.prec_imp, cimag(c), 
+		 pref.complex_sfx);
     prow = g_strconcat(prow, bff, NULL);
     g_free(trow);
     trow = prow;
@@ -217,7 +220,9 @@ loglist_show(void)
     trow = prow;
     for (ld = 0; ld < loglist.nr_lds; ld++) {
       c = loglist.elval[el * loglist.nr_lds + ld]; 
-      sprintf(bff, "%10.3f%+10.3f%s ", creal(c), cimag(c), pref.complex_sfx);
+      sprintf(bff, "%10.*f%+10.*f%s ", 
+		   pref.prec_imp, creal(c), pref.prec_imp, cimag(c), 
+		   pref.complex_sfx);
       prow = g_strconcat(prow, bff, NULL);
       g_free(trow);
       trow = prow;
@@ -293,7 +298,9 @@ loglist_export(void)
   fprintf(resf, _("     "));
   for (ld = 0; ld < loglist.nr_lds; ld++) {
     c = loglist.load[ld];  
-    fprintf(resf, "%10.3f%+10.3f%s ", creal(c), cimag(c), pref.complex_sfx);
+    fprintf(resf, "%10.*f%+10.*f%s ", 
+		  pref.prec_imp, creal(c), pref.prec_imp, cimag(c), 
+		  pref.complex_sfx);
   }
   fprintf(resf, "\n");
 
@@ -307,7 +314,9 @@ loglist_export(void)
     fprintf(resf, _("     "));
     for (ld = 0; ld < loglist.nr_lds; ld++) {
       c = loglist.elval[el * loglist.nr_lds + ld];
-      fprintf(resf, "%10.3f%+10.3f%s ", creal(c), cimag(c), pref.complex_sfx);
+      fprintf(resf, "%10.*f%+10.*f%s ",
+		    pref.prec_imp, creal(c), pref.prec_imp, cimag(c),
+		    pref.complex_sfx);
     }
     fprintf(resf, "\n");
     // then the circuit impedance or admittance
@@ -316,12 +325,12 @@ loglist_export(void)
       c = loglist.val[el * loglist.nr_lds + ld];
       if (is_imp || pref.always_imp) {
         fprintf(resf, "%10.*f%+10.*f%s ",
-		creal(c), pref.prec_imp, cimag(c), pref.prec_imp,
+		pref.prec_imp, creal(c), pref.prec_imp, cimag(c), 
 		pref.complex_sfx);
       } else {
 	c = pref.chart_z0*pref.chart_z0/c;
 	fprintf(resf, "%10.*f%+10.*f%s ",
-		creal(c), pref.prec_adm, cimag(c), pref.prec_adm,
+		pref.prec_adm, creal(c), pref.prec_adm, cimag(c), 
 		pref.complex_sfx);
       }
     }
