@@ -22,9 +22,16 @@
 #include <gtk/gtk.h>
 #include <complex.h>
 
-#define LOG_OVERHEAD	2
+enum {	LOG_ELEM,
+	LOG_Z_Y,
+	LOG_RESULT,
+	LOG_COLS
+};                                                                              
 
 void	loglist_initialize(GtkTreeView *tview);
 void	loglist_create(int nr_lds, int nr_els);
-void	loglist_set_value(int ldnr, int elnr, complex value);
+void	loglist_set_impedance(int ldnr, int elnr,
+		complex el_imp, complex imp, int type);
+void    loglist_set_load(int ldnr, double freq, complex imp);
 void	loglist_show(void);
+void	loglist_export(void);
